==> fly-qdm_2.9.6.tar.xz: fly-qdm/dm_common/widgets/loginwidget.h <==
#ifndef LOGINWIDGET_H
#define LOGINWIDGET_H

#include "dm_common_global.h"

#include <QWidget>
#include <QLabel>
#include <QTableWidget>
#include <QStackedWidget>
#include <QToolButton>
#include <QLineEdit>
#include <QComboBox>
#include <QFile>
#include <QGestureEvent>

#include "managers/localauthmanager.h"
#include "structures.h"
#include "themedescription.h"


class DM_COMMONSHARED_EXPORT LoginWidget : public QWidget
{
    Q_OBJECT

public:
    enum class AuthPage {
        UnknownPage = 0,
        ShortCutsEnterUsername,
        TextEnterUsername
    };

private:
    enum class CommonWidgetPage {
        UnknownPage = 0,
        Login,
        allUsers
    };

    enum class UsersWidgetPage {
        UnknownPage = 0,
        ChangeUserButton,
        ShortCutUsers
    };

public:
    explicit LoginWidget(QWidget* parent = nullptr);
    ~LoginWidget() override;

signals:
    void currentUserChanged(const QString& username);

public:
    void load(QWidget* sourceWidget, const ThemeDescription& description);

    void enableUserSelection(const bool enable = true);
    void enableLoginWidgets(const bool enable = true);
    void enableHostnameSelection(const bool enable = true);
    void enableCapsLock(const bool enable = true);
    void clearPassword();
    const QString currentUsername() const;
    void setFocusOnPassword();

    void setUsers(const UsersData& users);
    void setCurrentUser(const QString& username);

    AuthPage currentAuthPage() const;
    void setCurrentAuthPage(const AuthPage page);

signals:
    void loginRequest(const AuthData& data);
    void authPageChanged(const AuthPage page);

protected:
    bool eventFilter(QObject* watched, QEvent* event) override;

private slots:
    void loginToolButtonClicked();
    void loginUsernameToolButtonClicked();
    void changeUserToolButtonClicked();
    void userPagesWidgetPressed(const int row, const int column);
    void userPagesWidgetActivated(const int row, const int column);
    void passwordLineEditReturnPressed();
    void usernameLineEditReturnPressed();
    void passwordUsernameLineEditReturnPressed();

    void allUsersTableWidgetPressed(int row, int column);
    void shortUsersTableWidgetPressed(int row, int column);

    void changeSelectingUserShortcutActivated();
    void escapeKeyShortcutActivated();

    bool gestureEvent(QGestureEvent* event);
    void swipeTriggered(QSwipeGesture* event, QWidget* widget);

private:
    const QList<UsersData> splitUsersIntoPages(const UsersData& users) const;
    void setShortListUsers(const UsersData& users);
    void setAllListUsers(const UsersData& users);
    void setUsersPage(const int index);
    void setNextUsersPage();
    void setPreviosUsersPage();
    void setCurrentUserData(const UserData& data);

    CommonWidgetPage currentCommonWidgetPage() const;
    QWidget* currentCommonWidget() const;
    void setCurrentCommonWidgetPage(const CommonWidgetPage page);
    void setCommonStackedWidgetPage(const int index);
    void setCommonStackedWidgetPage(const QString& name);

    UsersWidgetPage currentUsersWidgetPage() const;
    void setCurrentUsersWidgetPage(const UsersWidgetPage page);
    void setUsersStackedWidgetPage(const int index);
    void setUsersStackedWidgetPage(const QString& name);

    void setLoginStackedWidgetPage(const int index);
    void setLoginStackedWidgetPage(const QString& name);

private:
    QLabel* m_userIconLabel;
    QLabel* m_usernameLabel;
    QLabel* m_userHostnameLabel;
    QTableWidget* m_shortUsersTableWidget;
    QTableWidget* m_allUsersTableWidget;
    QTableWidget* m_userPagesTableWidget;
    QStackedWidget* m_usersStackedWidget;
    QStackedWidget* m_commonStackedWidget;
    QToolButton* m_changeUserToolButton;
    QLineEdit* m_usernameLineEdit;
    QLineEdit* m_passwordUsernameLineEdit;
    QToolButton* m_loginUsernameToolButton;
    QComboBox* m_hostsComboBox;
    QLineEdit* m_passwordLineEdit;
    QToolButton* m_loginToolButton;
    QStackedWidget* m_loginStackedWidget;
    QWidget* m_userSelectionWidget;
    QLabel* m_capsLockLabel;
    QLabel* m_capsLockUsernameLabel;

    ThemeDescription m_themeDescription;
    QFile* m_verticalUserWidgetFile;
    QFile* m_horizontalUserWidgetFile;
    QList<UsersData> m_userPagesData;
    int m_shortUsersColumns;
    int m_allUsersRows;
    int m_allUsersColumns;
    QIcon m_whiteCircleIcon;
    QIcon m_emptyWhiteCircleIcon;
    int m_currentUsersPage;
};

#endif // LOGINWIDGET_H

==> fly-qdm_2.11.6.tar.xz: fly-qdm/dm_common/widgets/loginwidget.h <==
#ifndef LOGINWIDGET_H
#define LOGINWIDGET_H

#include "dm_common_global.h"

#include <QWidget>
#include <QLabel>
#include <QTableWidget>
#include <QStackedWidget>
#include <QToolButton>
#include <QLineEdit>
#include <QComboBox>
#include <QFile>
#include <QGestureEvent>

#include "managers/localauthmanager.h"
#include "structures.h"
#include "themedescription.h"


class DM_COMMONSHARED_EXPORT LoginWidget : public QWidget
{
    Q_OBJECT

public:
    enum class AuthPage {
        UnknownPage = 0,
        ShortCutsEnterUsername,
        TextEnterUsername
    };

private:
    enum class CommonWidgetPage {
        UnknownPage = 0,
        Login,
        allUsers
    };

    enum class UsersWidgetPage {
        UnknownPage = 0,
        ChangeUserButton,
        ShortCutUsers
    };

public:
    explicit LoginWidget(QWidget* parent = nullptr);
    ~LoginWidget() override;

signals:
    void currentUserChanged(const QString& username);

public:
    void load(QWidget* sourceWidget, const ThemeDescription& description);

    void enableUserSelection(const bool enable = true);
    void enableLoginWidgets(const bool enable = true);
    void enableHostnameSelection(const bool enable = true);
    void enableCapsLock(const bool enable = true);
    void enableTokenMessage(const bool enable);
    void clearPassword();
    const QString currentUsername() const;
    const QString currentPassword() const;
    void setFocusOnPassword();

    void setUsers(const UsersData& users, const bool &showTokenUsers);
    void setCurrentUser(const QString& username);

    AuthPage currentAuthPage() const;
    void setCurrentAuthPage(const AuthPage page);

signals:
    void loginRequest(const AuthData& data, const QString &host);
    void authPageChanged(const AuthPage page);

protected:
    bool eventFilter(QObject* watched, QEvent* event) override;

private slots:
    void loginToolButtonClicked();
    void loginUsernameToolButtonClicked();
    void changeUserToolButtonClicked();
    void userPagesWidgetPressed(const int row, const int column);
    void userPagesWidgetActivated(const int row, const int column);
    void passwordLineEditReturnPressed();
    void usernameLineEditReturnPressed();
    void passwordUsernameLineEditReturnPressed();

    void allUsersTableWidgetPressed(int row, int column);
    void shortUsersTableWidgetPressed(int row, int column);

    void changeSelectingUserShortcutActivated();
    void escapeKeyShortcutActivated();

    bool gestureEvent(QGestureEvent* event);
    void swipeTriggered(QSwipeGesture* event, QWidget* widget);

private:
    const QList<UsersData> splitUsersIntoPages(const UsersData& users) const;
    void setShortListUsers(const UsersData& users);
    void setAllListUsers(const UsersData& users);
    void setUserLists(const UsersData &users);
    void setUsersPage(const int index);
    void setNextUsersPage();
    void setPreviosUsersPage();
    void setCurrentUserData(const UserData& data);

    CommonWidgetPage currentCommonWidgetPage() const;
    QWidget* currentCommonWidget() const;
    void setCurrentCommonWidgetPage(const CommonWidgetPage page);
    void setCommonStackedWidgetPage(const int index);
    void setCommonStackedWidgetPage(const QString& name);

    UsersWidgetPage currentUsersWidgetPage() const;
    void setCurrentUsersWidgetPage(const UsersWidgetPage page);
    void setUsersStackedWidgetPage(const int index);
    void setUsersStackedWidgetPage(const QString& name);

    void setLoginStackedWidgetPage(const int index);
    void setLoginStackedWidgetPage(const QString& name);

private:
    QLabel* m_userIconLabel;
    QLabel* m_usernameLabel;
    QLabel* m_userHostnameLabel;
    QTableWidget* m_shortUsersTableWidget;
    QTableWidget* m_allUsersTableWidget;
    QTableWidget* m_userPagesTableWidget;
    QStackedWidget* m_usersStackedWidget;
    QStackedWidget* m_commonStackedWidget;
    QToolButton* m_changeUserToolButton;
    QLineEdit* m_usernameLineEdit;
    QLineEdit* m_passwordUsernameLineEdit;
    QToolButton* m_loginUsernameToolButton;
    QComboBox* m_hostsComboBox;
    QLineEdit* m_passwordLineEdit;
    QToolButton* m_loginToolButton;
    QStackedWidget* m_loginStackedWidget;
    QWidget* m_userSelectionWidget;
    QLabel* m_capsLockLabel;
    QLabel* m_capsLockUsernameLabel;

    ThemeDescription m_themeDescription;
    QFile* m_verticalUserWidgetFile;
    QFile* m_horizontalUserWidgetFile;
    QList<UsersData> m_userPagesData;
    int m_shortUsersColumns;
    int m_allUsersRows;
    int m_allUsersColumns;
    QIcon m_whiteCircleIcon;
    QIcon m_emptyWhiteCircleIcon;
    QIcon m_insertTokenIcon;
    int m_currentUsersPage;
    bool m_showTokenUsers;

    const QString m_insertTokenMessage = tr("Please, insert token");

public slots:
    void updateHostsList(const QStringList &hosts);
    void updateUsers(const UsersData& users);
};

#endif // LOGINWIDGET_H
